"""Module that contains the pydantic models to store and load the Trustpoint DevID Module data."""
from __future__ import annotations

from pydantic import BaseModel, ConfigDict


class DevIdCertificate(BaseModel):
    """The DevID Certificate model containing all DevID certificates."""
    model_config = ConfigDict(strict=True, extra='forbid')

    certificate_index: int = ...
    key_index: int = ...

    is_enabled: bool = ...
    is_idevid: bool = ...

    certificate: bytes = ...
    certificate_chain: list[bytes] = ...


class DevIdKey(BaseModel):
    """The DevID Key model containing all private and public key pairs."""
    model_config = ConfigDict(strict=True, extra='forbid')

    key_index: int = ...
    certificate_indices: list[int] = ...

    is_enabled: bool = ...
    is_idevid_key: bool = ...

    private_key: bytes = ...
    public_key: bytes = ...


class Inventory(BaseModel):
    """The inventory model containing all data corresponding to the Trustpoint DevID Module."""
    model_config = ConfigDict(strict=True, extra='forbid')

    next_key_index: int = ...
    next_certificate_index: int = ...

    devid_keys: dict[int, DevIdKey] = ...
    devid_certificates: dict[int, DevIdCertificate] = ...

    public_key_fingerprint_mapping: dict[str, int] = ...
    certificate_fingerprint_mapping: dict[str, int] = ...
